# -*- coding: utf-8 -*-
from cms.models.pluginmodel import CMSPlugin
from allink_core.core.loading import get_class, get_model
from allink_core.core.views import AllinkBaseCreateView
from allink_core.core_apps.allink_mandrill.config import MandrillConfig


ContactRequest = get_model('contact', 'ContactRequest')
ContactRequestPlugin = get_model('contact', 'ContactRequestPlugin')
ContactRequestForm = get_class('contact.forms', 'ContactRequestForm')
send_request_confirmation_email = get_class('contact.email', 'send_request_confirmation_email')
send_request_email = get_class('contact.email', 'send_request_email')

config = MandrillConfig()


class ContactRequestView(AllinkBaseCreateView):
    model = ContactRequest
    form_class = ContactRequestForm
    template_name = 'contact/forms/request.html'
    plugin = None

    def dispatch(self, *args, **kwargs):
        plugin_id = self.kwargs.pop('plugin_id', None)
        self.plugin = CMSPlugin.objects.get(id=plugin_id).get_plugin_instance()[0]
        return super(ContactRequestView, self).dispatch(*args, **kwargs)

    def form_valid(self, form):
        response = super(ContactRequestView, self).form_valid(form)
        self.send_mail()
        return response

    def send_mail(self):
        if self.plugin.send_internal_mail:
            send_request_email(self.get_form(), self.plugin)
        if self.plugin.send_external_mail:
            send_request_confirmation_email(self.get_form(), self.plugin)



# -*- coding: utf-8 -*-
from datetime import datetime
from django.db.models import Q
from allink_core.core.models.managers import AllinkCategoryModelQuerySet


class AllinkEventsQuerySet(AllinkCategoryModelQuerySet):
    def active(self):
        today = datetime.today()
        return self.filter(
            Q(status=1)
            & (Q(start__isnull=True) & Q(end__isnull=True))
            | ((Q(start__lte=today) & Q(end__isnull=True))
               | (Q(start__isnull=True) & Q(end__gte=today)))
            | (Q(start__lte=today) & Q(end__gte=today)))

    def latest(self):
        return self.active()\
            .order_by('entry_date', 'id')\
            .distinct('entry_date', 'id')

    def earliest(self):
        return self.active()\
            .order_by('-entry_date', 'id')\
            .distinct('entry_date', 'id')

    def category(self):
        return self.active()\
            .order_by('categories__tree_id', 'categories__lft', 'entry_date')\
            .distinct()

    def upcoming_entries(self):
        today = datetime.today()
        return self.filter(entry_date__gte=today)

    def past_entries(self):
        today = datetime.today()
        return self.filter(entry_date__lte=today)


AllinkEventsManager = AllinkEventsQuerySet.as_manager



# -*- coding: utf-8 -*-
import json
from django.http import HttpResponse
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.template.loader import render_to_string
from django.utils.module_loading import import_string
from django.views.generic import FormView

from allink_core.core_apps.allink_mailchimp.forms import SignupForm, SignupFormAdvanced
from allink_core.core_apps.allink_mailchimp.config import MailChimpConfig

config = MailChimpConfig()


class SignupViewBase(FormView):
    form_class = None
    template_name = None

    def __init__(self, **kwargs):
        super(SignupViewBase, self).__init__(**kwargs)
        if config.signup_form:
            self.form_class = import_string(config.signup_form)

    def form_invalid(self, form):
        """
        If the form is invalid, re-render the context data with the
        data-filled form and errors.
        """
        return self.render_to_response(self.get_context_data(form=form), status=206)

    def form_valid(self, form, **kwargs):
        context = super(SignupViewBase, self).get_context_data(**kwargs)
        try:
            form.save()
            json_context = {}
            json_context['rendered_content'] = render_to_string('allink_mailchimp/confirmation.html',
                                                                context=context, request=self.request)
            return HttpResponse(content=json.dumps(json_context), content_type='application/json', status=200)
        except:
            # sentry is not configured on localhost
            if not settings.RAVEN_CONFIG.get('dsn'):
                raise
            form.add_error(None, _('Something went wrong with your subscription. Please try again later.'))
            return self.render_to_response(self.get_context_data(form=form), status=206)

    def get_context_data(self, **kwargs):
        data = super(SignupViewBase, self).get_context_data(**kwargs)
        data['mailchimp_signup_form'] = data.get('form')
        return data


class SignupView(SignupViewBase):
    form_class = SignupForm
    template_name = 'allink_mailchimp/signup_form.html'


class SignupViewAdvanced(SignupViewBase):
    form_class = SignupFormAdvanced
    template_name = 'allink_mailchimp/signup_form_advanced.html'



import sys
import random
import string
from django.utils.translation import override
from django.conf import settings
from django.core.cache import cache
from django.urls import clear_url_caches
from django.test.client import RequestFactory
from parler.utils.context import switch_language
from cms.apphook_pool import apphook_pool
from cms.appresolver import clear_app_resolvers
from cms import api
from cms.exceptions import AppAlreadyRegistered
from allink_core.core_apps.allink_categories.models import AllinkCategory

__all__ = [
    'PageApphookMixin',
    'CategoriesMixin',
    'DataModelMixin',
    'DataModelTranslationMixin',
    'PluginModelMixin',
]


class PageApphookMixin:
    """
    Creates the following objects:

    root_page
    page
    plugin_page
    placeholder

    Cleans up cache and a bunch of cms related stuff.

    usage example attributes:

    apphook_object = NewsApphook
    apphook = 'NewsApphook'
    namespace = 'news'
    page_template = 'default.html'

    """
    apphook_object = None
    apphook = None
    namespace = None
    page_template = None

    def setUp(self):
        super().setUp()
        self.language = settings.LANGUAGES[0][0]
        apphook_object = self.get_apphook_object()
        self.reload_urls(apphook_object)

        self.root_page = api.create_page(
            title='root_page',
            template=self.page_template,
            language=self.language,
            published=True,
        )
        try:
            # Django-cms 3.5 doesn't set is_home when create_page is called
            self.root_page.set_as_homepage()
        except AttributeError:
            pass

        self.page = api.create_page(
            title='page',
            template=self.page_template,
            language=self.language,
            published=True,
            parent=self.root_page,
            apphook=self.apphook,
            apphook_namespace=self.namespace
        )
        self.plugin_page = api.create_page(
            title="plugin_page",
            template=self.page_template,
            language=self.language,
            parent=self.root_page,
            published=True
        )

        self.placeholder = self.page.placeholders.all()[0]

        # translated and publish all created pages
        for page in self.root_page, self.page, self.plugin_page:
            for language, _ in settings.LANGUAGES[1:]:
                api.create_title(language, '{}: {}'.format(page.get_slug(), language), page)
                page.publish(language)
                page.set_translations_cache()

    def tearDown(self):
        """
        Do a proper cleanup, delete everything what is preventing us from
        clean environment for tests.
        :return: None
        """
        self.reset_all()
        cache.clear()
        super(PageApphookMixin, self).tearDown()

    def get_apphook_object(self):
        return self.apphook_object

    def reset_all(self):
        """
        Reset all that could leak from previous test to current/next test.
        :return: None
        """
        apphook_object = self.get_apphook_object()
        self.delete_app_module(apphook_object.__module__)
        self.reload_urls(apphook_object)
        self.apphook_clear()

    def delete_app_module(self, app_module=None):
        """
        Remove APP_MODULE from sys.modules. Taken from cms.
        :return: None
        """
        if app_module is None:
            apphook_object = self.get_apphook_object()
            app_module = getattr(apphook_object, '__module__')
        if app_module in sys.modules:
            del sys.modules[app_module]

    def apphook_clear(self):
        """
        Clean up apphook_pool and sys.modules. Taken from cms with slight
        adjustments and fixes.
        :return: None
        """
        try:
            apphooks = apphook_pool.get_apphooks()
        except AppAlreadyRegistered:
            # there is an issue with discover apps, or i'm using it wrong.
            # setting discovered to True solves it. Maybe that is due to import
            # from aldryn_events.cms_apps which registers EventListAppHook
            apphook_pool.discovered = True
            apphooks = apphook_pool.get_apphooks()

        for name, label in list(apphooks):
            if apphook_pool.apps[name].__class__.__module__ in sys.modules:
                del sys.modules[apphook_pool.apps[name].__class__.__module__]
        apphook_pool.clear()

    def reload_urls(self, apphook_object=None):
        """
        Clean up url related things (caches, app resolvers, modules).
        Taken from cms.
        :return: None
        """
        if apphook_object is None:
            apphook_object = self.get_apphook_object()
        app_module = apphook_object.__module__
        package = app_module.split('.')[0]
        clear_app_resolvers()
        clear_url_caches()
        url_modules = [
            'cms.urls',
            '{0}.urls'.format(package),
            settings.ROOT_URLCONF
        ]

        for module in url_modules:
            if module in sys.modules:
                del sys.modules[module]


class CategoriesMixin:
    """
    Creates the following objects and its translation:

    category_root
    category_1
    category_2

    """

    def setUp(self):
        super().setUp()
        self.setup_categories()

    @staticmethod
    def reload(node):
        """NOTE: django-treebeard requires nodes to be reloaded via the Django
        ORM once its sub-tree is modified for the API to work properly.
        See:: https://tabo.pe/projects/django-treebeard/docs/2.0/caveats.html
        This is a simple helper-method to do that."""
        return node.__class__.objects.get(id=node.id)

    @classmethod
    def rand_str(cls, prefix=u'', length=23, chars=string.ascii_letters):
        return prefix + u''.join(random.choice(chars) for _ in range(length))

    def setup_categories(self):
        """
        Sets-up i18n categories (self.category_root, self.category_1 and
        self.category_2) for use in tests
        """
        self.language = settings.LANGUAGES[0][0]

        categories = []
        # Set the default language, create the objects
        with override(self.language):
            code = "{0}-".format(self.language)
            self.category_root = AllinkCategory.add_root(
                name=self.rand_str(prefix=code, length=8))
            categories.append(self.category_root)
            self.category_1 = self.category_root.add_child(
                name=self.rand_str(prefix=code, length=8))
            categories.append(self.category_1)
            self.category_2 = self.category_root.add_child(
                name=self.rand_str(prefix=code, length=8))
            categories.append(self.category_2)

        # We should reload category_root, since we modified its children.
        self.category_root = self.reload(self.category_root)

        # Setup the other language(s) translations for the categories
        for language, _ in settings.LANGUAGES[1:]:
            for category in categories:
                with switch_language(category, language):
                    code = "{0}-".format(language)
                    category.name = self.rand_str(prefix=code, length=8)
                    category.save()


class DataModelMixin:
    """
    Creates the following objects:

    allink_config
    entry_1
    entry_2
    entry_3
    entry_4
    entry_5

    usage example attributes:

    data_model_factory = NewsFactory

    """
    data_model_factory = None

    def setUp(self):
        from allink_core.apps.config.tests.factories import ConfigFactory
        super().setUp()
        self.allink_config = ConfigFactory()
        self.entry_1 = self.data_model_factory()
        self.entry_2 = self.data_model_factory()
        self.entry_3 = self.data_model_factory()
        self.entry_4 = self.data_model_factory()
        self.entry_5 = self.data_model_factory()


class DataModelTranslationMixin(DataModelMixin):
    """
    Creates the translations in languages de and fr for the following objects:

    entry_1
    entry_2
    entry_3
    entry_4
    entry_5

    """

    def setUp(self):
        super().setUp()
        entries = [self.entry_1, self.entry_2, self.entry_3, self.entry_4, self.entry_5]

        # Setup the other language(s) translations for the entries
        for language, _ in settings.LANGUAGES[1:]:
            for entry in entries:
                title = '{}-{}'.format(entry.title, language)
                with switch_language(entry, language):
                    entry.title = title
                    entry.save()


class PluginModelMixin(PageApphookMixin):
    """
    Creates the following objects:

    placeholder
    plugin_model_instance

    usage example attributes:

    plugin_class = CMSNewsAppContentPlugin
    load_more_view = NewsPluginLoadMore

    """
    plugin_class = None
    load_more_view = None

    def setUp(self):
        super().setUp()
        self.placeholder = self.plugin_page.placeholders.all()[0]
        self.plugin_model_instance = api.add_plugin(
            self.placeholder,
            self.plugin_class,
            self.language,
            # allink default values
            template='grid_static',
        )

    def get_load_more_view(self):
        """ returns a pseudo instantiated load_more_view """
        load_more_view = self.load_more_view()
        load_more_view.plugin = self.plugin_model_instance
        load_more_view.request = RequestFactory()
        load_more_view.request.GET = {}
        return load_more_view



# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from cms.admin.placeholderadmin import PlaceholderAdminMixin
from parler.admin import TranslatableAdmin
from allink_core.core.admin import AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin, \
    AllinkTeaserAdminMixin, AllinkCategoryAdminForm
from allink_core.core.loading import get_model
from allink_core.core.utils import get_additional_choices

Events = get_model('events', 'Events')
EventsRegistration = get_model('events', 'EventsRegistration')


class EventsContentAdminForm(AllinkCategoryAdminForm):

    def __init__(self, *args, **kwargs):
        super(EventsContentAdminForm, self).__init__(*args, **kwargs)

        if get_additional_choices('ADDITIONAL_EVENTS_DETAIL_TEMPLATES'):
            self.fields['template'] = forms.CharField(
                label='Template',
                widget=forms.Select(choices=get_additional_choices('ADDITIONAL_EVENTS_DETAIL_TEMPLATES', blank=True)),
                required=False,
            )
        else:
            self.fields['template'] = forms.CharField(widget=forms.HiddenInput(), required=False)


@admin.register(Events)
class EventsAdmin(AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin,
                  AllinkTeaserAdminMixin, PlaceholderAdminMixin,
                  TranslatableAdmin):
    form = EventsContentAdminForm
    list_display = ('title', 'status', 'all_categories_column', 'entry_date',)

    # entry_date = forms.DateTimeField(
    #     label=('Date and Time'),
    #     widget=forms.widgets.DateTimeInput(
    #         attrs={
    #             'placeholder': _('Please choose date and time'),
    #             'data-dateFormat': 'Y-m-d H:i',
    #             'data-altFormat': 'D, j. F Y, H:i',
    #             'data-minDate': str(datetime.date.today() - datetime.timedelta(days=180)),
    #             'data-maxDate': 'today',
    #             'data-enableTime': True,
    #         }
    #     ),
    # )

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'lead':
            kwargs['widget'] = forms.Textarea
        return super(EventsAdmin, self).formfield_for_dbfield(db_field, **kwargs)

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'status',
                    'title',
                    'slug',
                    'template',
                    'preview_image',
                    ('entry_date', 'costs',),
                    'lead',
                    'location',
                    'form_enabled',
                    'created',
                )
            }),
        )

        fieldsets += (
            ('Published From/To', {
                'classes': ('collapse',),
                'fields': (
                    'start',
                    'end',
                )
            }),
        )
        fieldsets += self.get_category_fieldsets()
        fieldsets += self.get_seo_fieldsets()
        return fieldsets


@admin.register(EventsRegistration)
class EventsRegistrationAdmin(admin.ModelAdmin):
    list_display = ('__str__', 'email', 'created', 'event', 'message',)
    list_filter = ('event',)



# -*- coding: utf-8 -*-
from django import forms
from django.conf import settings

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from allink_core.core_apps.allink_group.models import AllinkGroupContainerPlugin, AllinkGroupPlugin


class AllinkGroupContainerPluginForm(forms.ModelForm):

    class Meta:
        model = AllinkGroupContainerPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')


class AllinkGroupPluginForm(forms.ModelForm):

    class Meta:
        model = AllinkGroupPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')


@plugin_pool.register_plugin
class CMSAllinkGroupContainerPlugin(CMSPluginBase):
    model = AllinkGroupContainerPlugin
    name = 'Group Container'
    module = 'Generic'
    allow_children = True
    child_classes = ['CMSAllinkGroupPlugin', 'CMSAllinkButtonLinkContainerPlugin']
    form = AllinkGroupContainerPluginForm
    filter_vertical = ('groups', )

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'title',
                    'groups',
                ),
            }),
        )

        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_group/content.html'
        return template


@plugin_pool.register_plugin
class CMSAllinkGroupPlugin(CMSPluginBase):
    model = AllinkGroupPlugin
    name = 'Group'
    module = 'Generic'
    allow_children = True
    child_classes = settings.CMS_ALLINK_GROUP_PLUGIN_CHILD_CLASSES
    form = AllinkGroupPluginForm

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'title',
                ),
            }),
        )

        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_group/item.html'
        return template



# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from allink_core.core.loading import get_model

ContactRequest = get_model('contact', 'ContactRequest')


class ContactRequestAdmin(admin.ModelAdmin):
    list_display = ('__str__', 'created', 'modified', 'nicer_contact_type', 'date', 'time', 'message',)
    list_filter = ('contact_type', 'modified', )

    def nicer_contact_type(self, obj):
        return '{} ({})'.format(obj.get_contact_type_display(), obj.contact_details)

    nicer_contact_type.short_description = _('Contact via')


admin.site.register(ContactRequest, ContactRequestAdmin)



# -*- coding: utf-8 -*-
import datetime
from django import forms
from django.utils.translation import ugettext_lazy as _

from allink_core.core.loading import get_model
from allink_core.core.forms.forms import AllinkBaseModelForm


ContactRequest = get_model('contact', 'ContactRequest')


class ContactRequestForm(AllinkBaseModelForm):

    email = forms.CharField(
        label=_('E-Mail'),
        required=False
    )
    date = forms.DateField(
        label=_('Date'),
        widget=forms.TextInput(
            attrs={
                'class': 'datepicker',
                'placeholder': _('Please choose a date.')
            }),
        required=False
    )

    def clean_date(self):
        date = self.cleaned_data['date']
        contact_type = self.cleaned_data.get('contact_type')
        if date and date < datetime.date.today():
            raise forms.ValidationError(_('Date has to be in the future.'))

        if contact_type == ContactRequest.CONTACT_PHONE and not date:
            raise forms.ValidationError(_('This field is required.'))
        return date

    def clean_phone(self):
        contact_type = self.cleaned_data.get('contact_type')
        phone = self.cleaned_data['phone']
        if contact_type == ContactRequest.CONTACT_PHONE and not phone:
            raise forms.ValidationError(_('This field is required.'))
        return phone

    def clean_time(self):
        contact_type = self.cleaned_data.get('contact_type')
        time = self.cleaned_data['time']
        if contact_type == ContactRequest.CONTACT_PHONE and not time:
            raise forms.ValidationError(_('This field is required.'))
        return time

    def clean_email(self):
        contact_type = self.cleaned_data.get('contact_type')
        email = self.cleaned_data['email']
        if contact_type == ContactRequest.CONTACT_EMAIL and not email:
            raise forms.ValidationError(_('This field is required.'))
        return email

    class Meta:
        model = ContactRequest
        fields = ('salutation', 'first_name', 'last_name', 'company_name', 'contact_type', 'email',
                  'message', 'phone', 'date', 'time')



# -*- coding: utf-8 -*-
from django import forms
from parler.forms import TranslatableModelForm


class AllinkBaseModelForm(forms.ModelForm):
    pass


class AllinkBaseTranslatableModelForm(TranslatableModelForm):
    pass



# Generated by Django 2.1.8 on 2019-07-03 09:57

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContactRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('salutation', models.IntegerField(choices=[(1, 'Mr.'), (2, 'Mrs.')], null=True, verbose_name='Salutation')),
                ('first_name', models.CharField(max_length=255, null=True, verbose_name='First Name')),
                ('last_name', models.CharField(max_length=255, null=True, verbose_name='Last Name')),
                ('email', models.EmailField(max_length=254, null=True, verbose_name='Email')),
                ('company_name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Company')),
                ('phone', models.CharField(blank=True, max_length=30, null=True, verbose_name='Phone')),
                ('message', models.TextField(blank=True, max_length=255, null=True, verbose_name='Message')),
                ('contact_type', models.IntegerField(choices=[(None, '-- please choose --'), (10, 'Phone'), (20, 'Email')], verbose_name='Please contact me via')),
                ('date', models.DateField(blank=True, null=True, verbose_name='Date')),
                ('time', models.IntegerField(blank=True, choices=[(None, '-- between --'), (1, '09:00-11:00'), (2, '13:00-15:00'), (3, '15:00-17:00')], null=True, verbose_name='Time')),
            ],
            options={
                'verbose_name': 'Contact Request',
                'verbose_name_plural': 'Contact Requests',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactRequestPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='contact_contactrequestplugin', serialize=False, to='cms.CMSPlugin')),
                ('send_internal_mail', models.BooleanField(default=True, help_text='Send confirmation mail to defined internal e-mail addresses.', verbose_name='Send internal e-mail')),
                ('internal_email_addresses', django.contrib.postgres.fields.ArrayField(base_field=models.EmailField(blank=True, max_length=254, null=True), blank=True, null=True, size=None, verbose_name='Internal e-mail addresses')),
                ('from_email_address', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Sender e-mail address')),
                ('send_external_mail', models.BooleanField(default=True, help_text='Send confirmation mail to customer.', verbose_name='Send external e-mail')),
                ('thank_you_text', models.TextField(blank=True, help_text='This text will be shown, after form completion.', null=True, verbose_name='Thank you text')),
                ('label_layout', models.CharField(choices=[('stacked', 'Stacked with fields'), ('side_by_side', 'Side by side with fields'), ('placeholder', 'As placeholders')], default='stacked', max_length=15, verbose_name='Display labels')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# Generated by Django 2.1.8 on 2019-07-02 17:18

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion
import djangocms_text_ckeditor.fields
import parler.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkTerms',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateTimeField(blank=True, null=True, verbose_name='start')),
                ('end', models.DateTimeField(blank=True, null=True, verbose_name='end')),
                ('status', models.IntegerField(choices=[(10, 'Draft'), (20, 'Published'), (30, 'Archived')], default=10, verbose_name='Status')),
                ('terms_cms_page', cms.models.fields.PageField(help_text='CMS Page which shows Terms and Conditions', null=True, on_delete=django.db.models.deletion.PROTECT, to='cms.Page', verbose_name='Terms cms Page')),
            ],
            options={
                'verbose_name': 'Terms of Service',
                'verbose_name_plural': 'Terms of Service',
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='AllinkTermsPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_terms_allinktermsplugin', serialize=False, to='cms.CMSPlugin')),
            ],
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AllinkTermsTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('text', djangocms_text_ckeditor.fields.HTMLField(verbose_name='Terms Text')),
                ('master', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='allink_terms.AllinkTerms')),
            ],
            options={
                'verbose_name': 'Terms of Service Translation',
                'db_table': 'allink_terms_allinkterms_translation',
                'db_tablespace': '',
                'managed': True,
                'default_permissions': (),
            },
        ),
        migrations.AlterUniqueTogether(
            name='allinktermstranslation',
            unique_together={('language_code', 'master')},
        ),
    ]



# Generated by Django 2.1.8 on 2019-07-04 13:38

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('events', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='events',
            name='event_date_time',
        ),
        migrations.RemoveField(
            model_name='events',
            name='sort_order',
        ),
        migrations.AddField(
            model_name='events',
            name='entry_date',
            field=models.DateTimeField(default=datetime.datetime(2019, 7, 4, 13, 38, 8, 803814), verbose_name='Entry Date'),
            preserve_default=False,
        ),
    ]
